@@ -43,7 +43,6 @@ class CurveName(Enum):
     GBPSWAP = "GBPSWAP"
     GBPSWAP_Disc_OIS = "GBPSWAP DISC OIS"
     GBPSWAP_Fix_1D_OIS = "GBPSWAP FIX 1D OIS"
-    GBPSWAP_Fix_1Y_OIS = "GBPSWAP FIX 1Y OIS"
     GBPSWAP_Fix_3M_OIS = "GBPSWAP FIX 3M OIS"
     GBPSWAP_Fix_6M_OIS = "GBPSWAP FIX 6M OIS"
     GBPSWAP_Libor = "GBPSWAP LIBOR"
@@ -52,7 +51,6 @@ class CurveName(Enum):
     JPYSWAP = "JPYSWAP"
     JPYSWAP_Disc_OIS = "JPYSWAP DISC OIS"
     JPYSWAP_Fix_1D_OIS = "JPYSWAP FIX 1D OIS"
-    JPYSWAP_Fix_1Y_OIS = "JPYSWAP FIX 1Y OIS"
     JPYSWAP_Fix_3M_OIS = "JPYSWAP FIX 3M OIS"
     JPYSWAP_Fix_6M_OIS = "JPYSWAP FIX 6M OIS"
     JPYSWAP_Libor = "JPYSWAP LIBOR"
@@ -69,7 +67,6 @@ class CurveName(Enum):
     RUBSWAP = "RUBSWAP"
     RUBSWAP_Disc_OIS = "RUBSWAP DISC OIS"
     RUBSWAP_Fix_1D_OIS = "RUBSWAP FIX 1D OIS"
-    RUBSWAP_Fix_1Y_OIS = "RUBSWAP FIX 1Y OIS"
     RUBSWAP_Fix_3M_OIS = "RUBSWAP FIX 3M OIS"
     RUBSWAP_Fix_6M_OIS = "RUBSWAP FIX 6M OIS"
     RUBSWAP_Libor = "RUBSWAP LIBOR"
@@ -90,7 +87,6 @@ class CurveName(Enum):
     USDSWAP = "USDSWAP"
     USDSWAP_Disc_OIS = "USDSWAP DISC OIS"
     USDSWAP_Fix_1D_OIS = "USDSWAP FIX 1D OIS"
-    USDSWAP_Fix_1Y_OIS = "USDSWAP FIX 1Y OIS"
     USDSWAP_Fix_3M_OIS = "USDSWAP FIX 3M OIS"
     USDSWAP_Fix_6M_OIS = "USDSWAP FIX 6M OIS"
     USDSWAP_Libor = "USDSWAP LIBOR"
